import React, { useState } from 'react'
import Autosuggest, { InputProps, SuggestionsFetchRequestedParams } from 'react-autosuggest'
import { Contact } from '../../../types'
import ContactView from './Contact'

type Props = InputProps<Contact> & {
  onSelectContact(contact: Contact): void,
  getSuggestions(value: string): Promise<Contact[]>,
  getSuggestionValue(contact: Contact): string,
}

const ContactAutosuggest = ({ onSelectContact, getSuggestions, getSuggestionValue, ...inputProps }: Props) => {
  const [suggestions, setSuggestions] = useState<Contact[]>([])

  const updateSuggestions = async ({ value }: SuggestionsFetchRequestedParams) => {
    setSuggestions(await getSuggestions(value))
  }

  return (
    <Autosuggest<Contact>
      inputProps={inputProps}
      suggestions={suggestions}
      renderSuggestion={(contact) => <ContactView contact={contact} />}
      onSuggestionsClearRequested={() => setSuggestions([])}
      getSuggestionValue={getSuggestionValue}
      onSuggestionSelected={(_, { suggestion }) => onSelectContact(suggestion)}
      onSuggestionsFetchRequested={updateSuggestions}
    />
  )
}

export default ContactAutosuggest
