import React from 'react'
import Autocomplete, { AutocompleteProps } from '@material-ui/lab/Autocomplete'
import { Contact, ContactOptions } from '../../types'
import { ContactInput } from './styles'

type Props = {
  contacts: Contact[]
  contact: Contact
  label: string
  onChange(contact: ContactOptions): void
  getInputValue(contact: Contact): Contact
} & Pick<AutocompleteProps<Contact, undefined, undefined, undefined>, 'filterOptions'>

export const ContactAutocomplete = ({ contacts, label, onChange, contact, getInputValue, filterOptions }: Props) => {

  return (
    <Autocomplete
      value={getInputValue(contact)}
      onChange={(_, contact) => {
        if (contact) {
          onChange(contact)
        }
      }}
      options={contacts}
      getOptionLabel={({ isNewContact, name, phone }: ContactOptions) => {
        const concatString = phone ? `${name} ${phone}` : name
        return isNewContact ?
          `Add ${concatString}` :
          `${concatString}`
      }}
      filterOptions={filterOptions}
      size="small"
      renderInput={(params) => <ContactInput
        {...params}
        label={label}
        variant="outlined"
        InputProps={{ ...params.InputProps, type: 'search' }}
      />}
    />
  )
}